/*
 * (C) Copyright 2011
 * CompuLab Ltd. <www.compulab.co.il>
 * Ilya Ledvich <ilya@compulab.co.il>
 * Igor Grinberg <grinberg@compulab.co.il>
 *
 * X-Loader common board structures, functions and definitions
 * for the CM-T3x board family.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.
 */

#ifndef __CM_T3X_BOARD_H__
#define __CM_T3X_BOARD_H__

#include "prcm.h"

/* Board data table - board specific callback functions and data structures */
struct board_data {
	char *board_name;			/* Board name */
	char *u_boot_fname;			/* Board spec. U-Boot file */
	int (*board_init)(void);		/* Board specific init */
	int (*misc_init_r)(void);		/* Misc init */
	u32 (*get_mem_type)(void);		/* Board spec. get_mem_type() */
	int (*nand_init)(void);			/* Board spec. nand_init() */

	/* Early init functions - must be supplied! */
	void (*watchdog_init)(void);		/* Watchdog init */
	void (*try_unlock_memory)(void);	/* Try unlock memory */
	void (*set_muxconf_regs)(void);		/* Config Mux registers */
	void (*prcm_init)(void);		/* Init clocks for PRCM */
	void (*per_clocks_enable)(void);	/* Peripheral clocks enable */
	void (*setup_memory_controller)(void);	/* Setup memory controller */

	/* DPLL params - must be supplied! */
	struct dpll_param *core_dpll_param;	/* Array of CORE DPLL params */
	struct dpll_param *mpu_dpll_param;	/* Array of MPU DPLL params */
	struct dpll_param *iva_dpll_param;	/* Array of IVA DPLL params */

	/* Array of PER DPLL params - must be supplied on OMAP34XX SoCs */
	struct dpll_param *per_dpll_param;
	/* Array of PER DPLL params - must be supplied on OMAP36XX SoCs */
	struct dpll_per_36x_param *per_36x_dpll_param;

	u32 *nand_gpmc_config;			/* Array of NAND GPMC params */
};

extern int cpu_is_omap35xx(void);
extern int cpu_is_omap37xx(void);
extern int cpu_is_am35xx(void);

extern int cm_t3530_probe(struct board_data *data);
extern int cm_t3730_probe(struct board_data *data);
extern int cm_t3517_probe(struct board_data *data);

int cm_t3x_nand_init(u32 *gpmc_cfg);
void board_data_dump(void);

#endif /* __CM_T3X_BOARD_H__ */
